==> mpqc_2.0.4.orig.tar.gz: mpqc-2.0.4.orig/src/lib/chemistry/qc/oint3/i0111.cc <==
#include <chemistry/qc/oint3/build.h>
int BuildIntV3::i0111(){
/* the cost is 62 */
double t1;
double t2;
double t3;
double t4;
double t5;
double t6;
double t7;
double t8;
double t9;
double t10;
double t11;
double t12;
double t13;
double t14;
double t15;
double t16;
t1=0.5*int_v_ooze;
double***int_v_list0=int_v_list(0);
double**int_v_list00=int_v_list0[0];
double*int_v_list001=int_v_list00[1];
t2=t1*int_v_list001[0];
t1=int_v_W0-int_v_p340;
double*int_v_list002=int_v_list00[2];
t3=t1*int_v_list002[0];
t4=int_v_p340-int_v_r30;
t5=t4*int_v_list001[0];
t6=t5+t3;
t3=int_v_W0-int_v_p120;
t5=t3*t6;
t7=t5+t2;
t5=t1*int_v_list001[0];
double*int_v_list000=int_v_list00[0];
t1=t4*int_v_list000[0];
t4=t1+t5;
double**int_v_list01=int_v_list0[1];
double*int_v_list010=int_v_list01[0];
int_v_list010[2]=t4;
t1=int_v_p120-int_v_r10;
t5=t1*t4;
t8=t5+t7;
double***int_v_list1=int_v_list(1);
double**int_v_list11=int_v_list1[1];
double*int_v_list110=int_v_list11[0];
int_v_list110[8]=t8;
t5=int_v_W2-int_v_p342;
t7=t5*int_v_list002[0];
t9=int_v_p342-int_v_r32;
t10=t9*int_v_list001[0];
t11=t10+t7;
t7=t3*t11;
t10=t5*int_v_list001[0];
t5=t9*int_v_list000[0];
t9=t5+t10;
int_v_list010[1]=t9;
t5=t1*t9;
t10=t5+t7;
int_v_list110[7]=t10;
t5=int_v_W1-int_v_p341;
t7=t5*int_v_list002[0];
t12=int_v_p341-int_v_r31;
t13=t12*int_v_list001[0];
t14=t13+t7;
t7=t3*t14;
t3=t5*int_v_list001[0];
t5=t12*int_v_list000[0];
t12=t5+t3;
int_v_list010[0]=t12;
t3=t1*t12;
t1=t3+t7;
int_v_list110[6]=t1;
t3=int_v_W2-int_v_p122;
t5=t3*t6;
t7=int_v_p122-int_v_r12;
t13=t7*t4;
t15=t13+t5;
int_v_list110[5]=t15;
t5=t3*t11;
t13=t2+t5;
t5=t7*t9;
t16=t5+t13;
int_v_list110[4]=t16;
t5=t3*t14;
t3=t7*t12;
t7=t3+t5;
int_v_list110[3]=t7;
t3=int_v_W1-int_v_p121;
t5=t6*t3;
t6=int_v_p121-int_v_r11;
t13=t6*t4;
t4=t13+t5;
int_v_list110[2]=t4;
t5=t3*t11;
t11=t6*t9;
t9=t11+t5;
int_v_list110[1]=t9;
t5=t3*t14;
t3=t2+t5;
t2=t6*t12;
t5=t2+t3;
int_v_list110[0]=t5;
return 1;}

==> mpqc_2.2.2.orig.tar.gz: mpqc-2.2.2/src/lib/chemistry/qc/oint3/i0111.cc <==
#include <chemistry/qc/oint3/build.h>
int sc::BuildIntV3::i0111(){
/* the cost is 62 */
double t1;
double t2;
double t3;
double t4;
double t5;
double t6;
double t7;
double t8;
double t9;
double t10;
double t11;
double t12;
double t13;
double t14;
double t15;
double t16;
t1=0.5*int_v_ooze;
double***restrictxx int_v_list0=int_v_list(0);
double**restrictxx int_v_list00=int_v_list0[0];
double*restrictxx int_v_list001=int_v_list00[1];
t2=t1*int_v_list001[0];
t1=int_v_W0-int_v_p340;
double*restrictxx int_v_list002=int_v_list00[2];
t3=t1*int_v_list002[0];
t4=int_v_p340-int_v_r30;
t5=t4*int_v_list001[0];
t6=t5+t3;
t3=int_v_W0-int_v_p120;
t5=t3*t6;
t7=t5+t2;
t5=t1*int_v_list001[0];
double*restrictxx int_v_list000=int_v_list00[0];
t1=t4*int_v_list000[0];
t4=t1+t5;
double**restrictxx int_v_list01=int_v_list0[1];
double*restrictxx int_v_list010=int_v_list01[0];
int_v_list010[2]=t4;
t1=int_v_p120-int_v_r10;
t5=t1*t4;
t8=t5+t7;
double***restrictxx int_v_list1=int_v_list(1);
double**restrictxx int_v_list11=int_v_list1[1];
double*restrictxx int_v_list110=int_v_list11[0];
int_v_list110[8]=t8;
t5=int_v_W2-int_v_p342;
t7=t5*int_v_list002[0];
t9=int_v_p342-int_v_r32;
t10=t9*int_v_list001[0];
t11=t10+t7;
t7=t3*t11;
t10=t5*int_v_list001[0];
t5=t9*int_v_list000[0];
t9=t5+t10;
int_v_list010[1]=t9;
t5=t1*t9;
t10=t5+t7;
int_v_list110[7]=t10;
t5=int_v_W1-int_v_p341;
t7=t5*int_v_list002[0];
t12=int_v_p341-int_v_r31;
t13=t12*int_v_list001[0];
t14=t13+t7;
t7=t3*t14;
t3=t5*int_v_list001[0];
t5=t12*int_v_list000[0];
t12=t5+t3;
int_v_list010[0]=t12;
t3=t1*t12;
t1=t3+t7;
int_v_list110[6]=t1;
t3=int_v_W2-int_v_p122;
t5=t3*t6;
t7=int_v_p122-int_v_r12;
t13=t7*t4;
t15=t13+t5;
int_v_list110[5]=t15;
t5=t3*t11;
t13=t2+t5;
t5=t7*t9;
t16=t5+t13;
int_v_list110[4]=t16;
t5=t3*t14;
t3=t7*t12;
t7=t3+t5;
int_v_list110[3]=t7;
t3=int_v_W1-int_v_p121;
t5=t6*t3;
t6=int_v_p121-int_v_r11;
t13=t6*t4;
t4=t13+t5;
int_v_list110[2]=t4;
t5=t3*t11;
t11=t6*t9;
t9=t11+t5;
int_v_list110[1]=t9;
t5=t3*t14;
t3=t2+t5;
t2=t6*t12;
t5=t2+t3;
int_v_list110[0]=t5;
return 1;}
